from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_shield_zone_item_request_builder import WithShieldZoneItemRequestBuilder

class CustomRulesRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /shield/waf/custom-rules
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new CustomRulesRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/shield/waf/custom-rules", path_parameters)
    
    def by_shield_zone_id(self,shield_zone_id: int) -> WithShieldZoneItemRequestBuilder:
        """
        Gets an item from the BunnyApiClient.shield.waf.customRules.item collection
        param shield_zone_id: Unique identifier of the item
        Returns: WithShieldZoneItemRequestBuilder
        """
        if shield_zone_id is None:
            raise TypeError("shield_zone_id cannot be null.")
        from .item.with_shield_zone_item_request_builder import WithShieldZoneItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["shieldZoneId"] = shield_zone_id
        return WithShieldZoneItemRequestBuilder(self.request_adapter, url_tpl_params)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .item.with_pull_zone_item_request_builder import WithPullZoneItemRequestBuilder

class GetByPullzoneRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /shield/shield-zone/get-by-pullzone
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new GetByPullzoneRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/shield/shield-zone/get-by-pullzone", path_parameters)
    
    def by_pull_zone_id(self,pull_zone_id: int) -> WithPullZoneItemRequestBuilder:
        """
        Gets an item from the BunnyApiClient.shield.shieldZone.getByPullzone.item collection
        param pull_zone_id: Unique identifier of the item
        Returns: WithPullZoneItemRequestBuilder
        """
        if pull_zone_id is None:
            raise TypeError("pull_zone_id cannot be null.")
        from .item.with_pull_zone_item_request_builder import WithPullZoneItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["pullZoneId"] = pull_zone_id
        return WithPullZoneItemRequestBuilder(self.request_adapter, url_tpl_params)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .waf_rule_model import WafRuleModel

@dataclass
class WafRuleGroupModel(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The code property
    code: Optional[str] = None
    # The description property
    description: Optional[str] = None
    # The fileName property
    file_name: Optional[str] = None
    # The id property
    id: Optional[int] = None
    # The mainGroup property
    main_group: Optional[str] = None
    # The name property
    name: Optional[str] = None
    # The rules property
    rules: Optional[List[WafRuleModel]] = None
    # The ruleset property
    ruleset: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> WafRuleGroupModel:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: WafRuleGroupModel
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return WafRuleGroupModel()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .waf_rule_model import WafRuleModel

        from .waf_rule_model import WafRuleModel

        fields: Dict[str, Callable[[Any], None]] = {
            "code": lambda n : setattr(self, 'code', n.get_str_value()),
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "fileName": lambda n : setattr(self, 'file_name', n.get_str_value()),
            "id": lambda n : setattr(self, 'id', n.get_int_value()),
            "mainGroup": lambda n : setattr(self, 'main_group', n.get_str_value()),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
            "rules": lambda n : setattr(self, 'rules', n.get_collection_of_object_values(WafRuleModel)),
            "ruleset": lambda n : setattr(self, 'ruleset', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("code", self.code)
        writer.write_str_value("description", self.description)
        writer.write_str_value("fileName", self.file_name)
        writer.write_int_value("id", self.id)
        writer.write_str_value("mainGroup", self.main_group)
        writer.write_str_value("name", self.name)
        writer.write_collection_of_object_values("rules", self.rules)
        writer.write_str_value("ruleset", self.ruleset)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .custom_rule.custom_rule_request_builder import CustomRuleRequestBuilder
    from .custom_rules.custom_rules_request_builder import CustomRulesRequestBuilder
    from .engine_config.engine_config_request_builder import EngineConfigRequestBuilder
    from .enums.enums_request_builder import EnumsRequestBuilder
    from .profiles.profiles_request_builder import ProfilesRequestBuilder
    from .rules.rules_request_builder import RulesRequestBuilder

class WafRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /shield/waf
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new WafRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/shield/waf", path_parameters)
    
    @property
    def custom_rule(self) -> CustomRuleRequestBuilder:
        """
        The customRule property
        """
        from .custom_rule.custom_rule_request_builder import CustomRuleRequestBuilder

        return CustomRuleRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def custom_rules(self) -> CustomRulesRequestBuilder:
        """
        The customRules property
        """
        from .custom_rules.custom_rules_request_builder import CustomRulesRequestBuilder

        return CustomRulesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def engine_config(self) -> EngineConfigRequestBuilder:
        """
        The engineConfig property
        """
        from .engine_config.engine_config_request_builder import EngineConfigRequestBuilder

        return EngineConfigRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def enums(self) -> EnumsRequestBuilder:
        """
        The enums property
        """
        from .enums.enums_request_builder import EnumsRequestBuilder

        return EnumsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def profiles(self) -> ProfilesRequestBuilder:
        """
        The profiles property
        """
        from .profiles.profiles_request_builder import ProfilesRequestBuilder

        return ProfilesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rules(self) -> RulesRequestBuilder:
        """
        The rules property
        """
        from .rules.rules_request_builder import RulesRequestBuilder

        return RulesRequestBuilder(self.request_adapter, self.path_parameters)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .blocked.blocked_request_builder import BlockedRequestBuilder
    from .logged.logged_request_builder import LoggedRequestBuilder
    from .processed.processed_request_builder import ProcessedRequestBuilder
    from .triggered.triggered_request_builder import TriggeredRequestBuilder

class WafRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /shield/metrics/waf
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new WafRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/shield/metrics/waf", path_parameters)
    
    @property
    def blocked(self) -> BlockedRequestBuilder:
        """
        The blocked property
        """
        from .blocked.blocked_request_builder import BlockedRequestBuilder

        return BlockedRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def logged(self) -> LoggedRequestBuilder:
        """
        The logged property
        """
        from .logged.logged_request_builder import LoggedRequestBuilder

        return LoggedRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def processed(self) -> ProcessedRequestBuilder:
        """
        The processed property
        """
        from .processed.processed_request_builder import ProcessedRequestBuilder

        return ProcessedRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def triggered(self) -> TriggeredRequestBuilder:
        """
        The triggered property
        """
        from .triggered.triggered_request_builder import TriggeredRequestBuilder

        return TriggeredRequestBuilder(self.request_adapter, self.path_parameters)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .integration import Integration

@dataclass
class ScriptCreate(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The Code property
    code: Optional[str] = None
    # The CreateLinkedPullZone property
    create_linked_pull_zone: Optional[bool] = None
    # The Integration property
    integration: Optional[Integration] = None
    # The Name property
    name: Optional[str] = None
    # The ScriptType property
    script_type: Optional[float] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ScriptCreate:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ScriptCreate
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ScriptCreate()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .integration import Integration

        from .integration import Integration

        fields: Dict[str, Callable[[Any], None]] = {
            "Code": lambda n : setattr(self, 'code', n.get_str_value()),
            "CreateLinkedPullZone": lambda n : setattr(self, 'create_linked_pull_zone', n.get_bool_value()),
            "Integration": lambda n : setattr(self, 'integration', n.get_object_value(Integration)),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "ScriptType": lambda n : setattr(self, 'script_type', n.get_float_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("Code", self.code)
        writer.write_bool_value("CreateLinkedPullZone", self.create_linked_pull_zone)
        writer.write_object_value("Integration", self.integration)
        writer.write_str_value("Name", self.name)
        writer.write_float_value("ScriptType", self.script_type)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.request_adapter import RequestAdapter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .metrics.metrics_request_builder import MetricsRequestBuilder
    from .rate_limit.rate_limit_request_builder import RateLimitRequestBuilder
    from .rate_limits.rate_limits_request_builder import RateLimitsRequestBuilder
    from .shield_zone.shield_zone_request_builder import ShieldZoneRequestBuilder
    from .shield_zones.shield_zones_request_builder import ShieldZonesRequestBuilder
    from .waf.waf_request_builder import WafRequestBuilder

class ShieldRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /shield
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new ShieldRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/shield", path_parameters)
    
    @property
    def metrics(self) -> MetricsRequestBuilder:
        """
        The metrics property
        """
        from .metrics.metrics_request_builder import MetricsRequestBuilder

        return MetricsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rate_limit(self) -> RateLimitRequestBuilder:
        """
        The rateLimit property
        """
        from .rate_limit.rate_limit_request_builder import RateLimitRequestBuilder

        return RateLimitRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rate_limits(self) -> RateLimitsRequestBuilder:
        """
        The rateLimits property
        """
        from .rate_limits.rate_limits_request_builder import RateLimitsRequestBuilder

        return RateLimitsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def shield_zone(self) -> ShieldZoneRequestBuilder:
        """
        The shieldZone property
        """
        from .shield_zone.shield_zone_request_builder import ShieldZoneRequestBuilder

        return ShieldZoneRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def shield_zones(self) -> ShieldZonesRequestBuilder:
        """
        The shieldZones property
        """
        from .shield_zones.shield_zones_request_builder import ShieldZonesRequestBuilder

        return ShieldZonesRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def waf(self) -> WafRequestBuilder:
        """
        The waf property
        """
        from .waf.waf_request_builder import WafRequestBuilder

        return WafRequestBuilder(self.request_adapter, self.path_parameters)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from ..models.pull_zone.pull_zone import PullZone
    from ..models.pull_zone.pull_zone_create import PullZoneCreate
    from .checkavailability.checkavailability_request_builder import CheckavailabilityRequestBuilder
    from .item.item_request_builder import ItemRequestBuilder
    from .load_free_certificate.load_free_certificate_request_builder import LoadFreeCertificateRequestBuilder
    from .pullzone_get_response import PullzoneGetResponse
    from .set_zone_security_enabled.set_zone_security_enabled_request_builder import SetZoneSecurityEnabledRequestBuilder
    from .set_zone_security_include_hash_remote_i_p_enabled.set_zone_security_include_hash_remote_i_p_enabled_request_builder import SetZoneSecurityIncludeHashRemoteIPEnabledRequestBuilder

class PullzoneRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /pullzone
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]]) -> None:
        """
        Instantiates a new PullzoneRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/pullzone?includeCertificate={includeCertificate}&page={page}&perPage={perPage}{&search}", path_parameters)
    
    def by_id(self,id: int) -> ItemRequestBuilder:
        """
        Gets an item from the BunnyApiClient.pullzone.item collection
        param id: The ID of the Pull Zone that should be returned
        Returns: ItemRequestBuilder
        """
        if id is None:
            raise TypeError("id cannot be null.")
        from .item.item_request_builder import ItemRequestBuilder

        url_tpl_params = get_path_parameters(self.path_parameters)
        url_tpl_params["%2Did"] = id
        return ItemRequestBuilder(self.request_adapter, url_tpl_params)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[PullzoneRequestBuilderGetQueryParameters]] = None) -> Optional[PullzoneGetResponse]:
        """
        [ListPullZones API Docs](https://docs.bunny.net/reference/pullzonepublic_index)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[PullzoneGetResponse]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from .pullzone_get_response import PullzoneGetResponse

        return await self.request_adapter.send_async(request_info, PullzoneGetResponse, None)
    
    async def post(self,body: PullZoneCreate, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[PullZone]:
        """
        [AddPullZone API Docs](https://docs.bunny.net/reference/pullzonepublic_add)
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[PullZone]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_post_request_information(
            body, request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ..models.pull_zone.pull_zone import PullZone

        return await self.request_adapter.send_async(request_info, PullZone, None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[PullzoneRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [ListPullZones API Docs](https://docs.bunny.net/reference/pullzonepublic_index)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_post_request_information(self,body: PullZoneCreate, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        [AddPullZone API Docs](https://docs.bunny.net/reference/pullzonepublic_add)
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.POST, '{+baseurl}/pullzone', self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> PullzoneRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: PullzoneRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return PullzoneRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def checkavailability(self) -> CheckavailabilityRequestBuilder:
        """
        The checkavailability property
        """
        from .checkavailability.checkavailability_request_builder import CheckavailabilityRequestBuilder

        return CheckavailabilityRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def load_free_certificate(self) -> LoadFreeCertificateRequestBuilder:
        """
        The loadFreeCertificate property
        """
        from .load_free_certificate.load_free_certificate_request_builder import LoadFreeCertificateRequestBuilder

        return LoadFreeCertificateRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def set_zone_security_enabled(self) -> SetZoneSecurityEnabledRequestBuilder:
        """
        The setZoneSecurityEnabled property
        """
        from .set_zone_security_enabled.set_zone_security_enabled_request_builder import SetZoneSecurityEnabledRequestBuilder

        return SetZoneSecurityEnabledRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def set_zone_security_include_hash_remote_i_p_enabled(self) -> SetZoneSecurityIncludeHashRemoteIPEnabledRequestBuilder:
        """
        The setZoneSecurityIncludeHashRemoteIPEnabled property
        """
        from .set_zone_security_include_hash_remote_i_p_enabled.set_zone_security_include_hash_remote_i_p_enabled_request_builder import SetZoneSecurityIncludeHashRemoteIPEnabledRequestBuilder

        return SetZoneSecurityIncludeHashRemoteIPEnabledRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class PullzoneRequestBuilderGetQueryParameters():
        """
        [ListPullZones API Docs](https://docs.bunny.net/reference/pullzonepublic_index)
        """
        def get_query_parameter(self,original_name: str) -> str:
            """
            Maps the query parameters names to their encoded names for the URI template parsing.
            param original_name: The original query parameter name in the class.
            Returns: str
            """
            if original_name is None:
                raise TypeError("original_name cannot be null.")
            if original_name == "include_certificate":
                return "includeCertificate"
            if original_name == "per_page":
                return "perPage"
            if original_name == "page":
                return "page"
            if original_name == "search":
                return "search"
            return original_name
        
        # Determines if the result hostnames should contain the SSL certificate
        include_certificate: Optional[bool] = None

        page: Optional[int] = None

        per_page: Optional[int] = None

        # The search term that will be used to filter the results
        search: Optional[str] = None

    
    @dataclass
    class PullzoneRequestBuilderGetRequestConfiguration(RequestConfiguration[PullzoneRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class PullzoneRequestBuilderPostRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

@dataclass
class CreateCustomWafRuleModel_variableTypes(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The ARGS property
    a_r_g_s: Optional[str] = None
    # The ARGS_COMBINED_SIZE property
    a_r_g_s_c_o_m_b_i_n_e_d_s_i_z_e: Optional[str] = None
    # The ARGS_GET property
    a_r_g_s_g_e_t: Optional[str] = None
    # The ARGS_GET_NAMES property
    a_r_g_s_g_e_t_n_a_m_e_s: Optional[str] = None
    # The ARGS_POST property
    a_r_g_s_p_o_s_t: Optional[str] = None
    # The ARGS_POST_NAMES property
    a_r_g_s_p_o_s_t_n_a_m_e_s: Optional[str] = None
    # The FILES_NAMES property
    f_i_l_e_s_n_a_m_e_s: Optional[str] = None
    # The GEO property
    g_e_o: Optional[str] = None
    # The QUERY_STRING property
    q_u_e_r_y_s_t_r_i_n_g: Optional[str] = None
    # The REMOTE_ADDR property
    r_e_m_o_t_e_a_d_d_r: Optional[str] = None
    # The REQUEST_BASENAME property
    r_e_q_u_e_s_t_b_a_s_e_n_a_m_e: Optional[str] = None
    # The REQUEST_BODY property
    r_e_q_u_e_s_t_b_o_d_y: Optional[str] = None
    # The REQUEST_COOKIES property
    r_e_q_u_e_s_t_c_o_o_k_i_e_s: Optional[str] = None
    # The REQUEST_COOKIES_NAMES property
    r_e_q_u_e_s_t_c_o_o_k_i_e_s_n_a_m_e_s: Optional[str] = None
    # The REQUEST_FILENAME property
    r_e_q_u_e_s_t_f_i_l_e_n_a_m_e: Optional[str] = None
    # The REQUEST_HEADERS property
    r_e_q_u_e_s_t_h_e_a_d_e_r_s: Optional[str] = None
    # The REQUEST_HEADERS_NAMES property
    r_e_q_u_e_s_t_h_e_a_d_e_r_s_n_a_m_e_s: Optional[str] = None
    # The REQUEST_LINE property
    r_e_q_u_e_s_t_l_i_n_e: Optional[str] = None
    # The REQUEST_METHOD property
    r_e_q_u_e_s_t_m_e_t_h_o_d: Optional[str] = None
    # The REQUEST_PROTOCOL property
    r_e_q_u_e_s_t_p_r_o_t_o_c_o_l: Optional[str] = None
    # The REQUEST_URI property
    r_e_q_u_e_s_t_u_r_i: Optional[str] = None
    # The REQUEST_URI_RAW property
    r_e_q_u_e_s_t_u_r_i_r_a_w: Optional[str] = None
    # The RESPONSE_BODY property
    r_e_s_p_o_n_s_e_b_o_d_y: Optional[str] = None
    # The RESPONSE_HEADERS property
    r_e_s_p_o_n_s_e_h_e_a_d_e_r_s: Optional[str] = None
    # The RESPONSE_STATUS property
    r_e_s_p_o_n_s_e_s_t_a_t_u_s: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> CreateCustomWafRuleModel_variableTypes:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: CreateCustomWafRuleModel_variableTypes
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return CreateCustomWafRuleModel_variableTypes()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        fields: Dict[str, Callable[[Any], None]] = {
            "ARGS": lambda n : setattr(self, 'a_r_g_s', n.get_str_value()),
            "ARGS_COMBINED_SIZE": lambda n : setattr(self, 'a_r_g_s_c_o_m_b_i_n_e_d_s_i_z_e', n.get_str_value()),
            "ARGS_GET": lambda n : setattr(self, 'a_r_g_s_g_e_t', n.get_str_value()),
            "ARGS_GET_NAMES": lambda n : setattr(self, 'a_r_g_s_g_e_t_n_a_m_e_s', n.get_str_value()),
            "ARGS_POST": lambda n : setattr(self, 'a_r_g_s_p_o_s_t', n.get_str_value()),
            "ARGS_POST_NAMES": lambda n : setattr(self, 'a_r_g_s_p_o_s_t_n_a_m_e_s', n.get_str_value()),
            "FILES_NAMES": lambda n : setattr(self, 'f_i_l_e_s_n_a_m_e_s', n.get_str_value()),
            "GEO": lambda n : setattr(self, 'g_e_o', n.get_str_value()),
            "QUERY_STRING": lambda n : setattr(self, 'q_u_e_r_y_s_t_r_i_n_g', n.get_str_value()),
            "REMOTE_ADDR": lambda n : setattr(self, 'r_e_m_o_t_e_a_d_d_r', n.get_str_value()),
            "REQUEST_BASENAME": lambda n : setattr(self, 'r_e_q_u_e_s_t_b_a_s_e_n_a_m_e', n.get_str_value()),
            "REQUEST_BODY": lambda n : setattr(self, 'r_e_q_u_e_s_t_b_o_d_y', n.get_str_value()),
            "REQUEST_COOKIES": lambda n : setattr(self, 'r_e_q_u_e_s_t_c_o_o_k_i_e_s', n.get_str_value()),
            "REQUEST_COOKIES_NAMES": lambda n : setattr(self, 'r_e_q_u_e_s_t_c_o_o_k_i_e_s_n_a_m_e_s', n.get_str_value()),
            "REQUEST_FILENAME": lambda n : setattr(self, 'r_e_q_u_e_s_t_f_i_l_e_n_a_m_e', n.get_str_value()),
            "REQUEST_HEADERS": lambda n : setattr(self, 'r_e_q_u_e_s_t_h_e_a_d_e_r_s', n.get_str_value()),
            "REQUEST_HEADERS_NAMES": lambda n : setattr(self, 'r_e_q_u_e_s_t_h_e_a_d_e_r_s_n_a_m_e_s', n.get_str_value()),
            "REQUEST_LINE": lambda n : setattr(self, 'r_e_q_u_e_s_t_l_i_n_e', n.get_str_value()),
            "REQUEST_METHOD": lambda n : setattr(self, 'r_e_q_u_e_s_t_m_e_t_h_o_d', n.get_str_value()),
            "REQUEST_PROTOCOL": lambda n : setattr(self, 'r_e_q_u_e_s_t_p_r_o_t_o_c_o_l', n.get_str_value()),
            "REQUEST_URI": lambda n : setattr(self, 'r_e_q_u_e_s_t_u_r_i', n.get_str_value()),
            "REQUEST_URI_RAW": lambda n : setattr(self, 'r_e_q_u_e_s_t_u_r_i_r_a_w', n.get_str_value()),
            "RESPONSE_BODY": lambda n : setattr(self, 'r_e_s_p_o_n_s_e_b_o_d_y', n.get_str_value()),
            "RESPONSE_HEADERS": lambda n : setattr(self, 'r_e_s_p_o_n_s_e_h_e_a_d_e_r_s', n.get_str_value()),
            "RESPONSE_STATUS": lambda n : setattr(self, 'r_e_s_p_o_n_s_e_s_t_a_t_u_s', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("ARGS", self.a_r_g_s)
        writer.write_str_value("ARGS_COMBINED_SIZE", self.a_r_g_s_c_o_m_b_i_n_e_d_s_i_z_e)
        writer.write_str_value("ARGS_GET", self.a_r_g_s_g_e_t)
        writer.write_str_value("ARGS_GET_NAMES", self.a_r_g_s_g_e_t_n_a_m_e_s)
        writer.write_str_value("ARGS_POST", self.a_r_g_s_p_o_s_t)
        writer.write_str_value("ARGS_POST_NAMES", self.a_r_g_s_p_o_s_t_n_a_m_e_s)
        writer.write_str_value("FILES_NAMES", self.f_i_l_e_s_n_a_m_e_s)
        writer.write_str_value("GEO", self.g_e_o)
        writer.write_str_value("QUERY_STRING", self.q_u_e_r_y_s_t_r_i_n_g)
        writer.write_str_value("REMOTE_ADDR", self.r_e_m_o_t_e_a_d_d_r)
        writer.write_str_value("REQUEST_BASENAME", self.r_e_q_u_e_s_t_b_a_s_e_n_a_m_e)
        writer.write_str_value("REQUEST_BODY", self.r_e_q_u_e_s_t_b_o_d_y)
        writer.write_str_value("REQUEST_COOKIES", self.r_e_q_u_e_s_t_c_o_o_k_i_e_s)
        writer.write_str_value("REQUEST_COOKIES_NAMES", self.r_e_q_u_e_s_t_c_o_o_k_i_e_s_n_a_m_e_s)
        writer.write_str_value("REQUEST_FILENAME", self.r_e_q_u_e_s_t_f_i_l_e_n_a_m_e)
        writer.write_str_value("REQUEST_HEADERS", self.r_e_q_u_e_s_t_h_e_a_d_e_r_s)
        writer.write_str_value("REQUEST_HEADERS_NAMES", self.r_e_q_u_e_s_t_h_e_a_d_e_r_s_n_a_m_e_s)
        writer.write_str_value("REQUEST_LINE", self.r_e_q_u_e_s_t_l_i_n_e)
        writer.write_str_value("REQUEST_METHOD", self.r_e_q_u_e_s_t_m_e_t_h_o_d)
        writer.write_str_value("REQUEST_PROTOCOL", self.r_e_q_u_e_s_t_p_r_o_t_o_c_o_l)
        writer.write_str_value("REQUEST_URI", self.r_e_q_u_e_s_t_u_r_i)
        writer.write_str_value("REQUEST_URI_RAW", self.r_e_q_u_e_s_t_u_r_i_r_a_w)
        writer.write_str_value("RESPONSE_BODY", self.r_e_s_p_o_n_s_e_b_o_d_y)
        writer.write_str_value("RESPONSE_HEADERS", self.r_e_s_p_o_n_s_e_h_e_a_d_e_r_s)
        writer.write_str_value("RESPONSE_STATUS", self.r_e_s_p_o_n_s_e_s_t_a_t_u_s)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .create_custom_waf_rule_model_variable_types import CreateCustomWafRuleModel_variableTypes

@dataclass
class CreateCustomWafRuleModel(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The actionType property
    action_type: Optional[float] = None
    # The operatorType property
    operator_type: Optional[float] = None
    # The severityType property
    severity_type: Optional[float] = None
    # The transformationTypes property
    transformation_types: Optional[List[float]] = None
    # The value property
    value: Optional[str] = None
    # The variableTypes property
    variable_types: Optional[CreateCustomWafRuleModel_variableTypes] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> CreateCustomWafRuleModel:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: CreateCustomWafRuleModel
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return CreateCustomWafRuleModel()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .create_custom_waf_rule_model_variable_types import CreateCustomWafRuleModel_variableTypes

        from .create_custom_waf_rule_model_variable_types import CreateCustomWafRuleModel_variableTypes

        fields: Dict[str, Callable[[Any], None]] = {
            "actionType": lambda n : setattr(self, 'action_type', n.get_float_value()),
            "operatorType": lambda n : setattr(self, 'operator_type', n.get_float_value()),
            "severityType": lambda n : setattr(self, 'severity_type', n.get_float_value()),
            "transformationTypes": lambda n : setattr(self, 'transformation_types', n.get_collection_of_primitive_values(float)),
            "value": lambda n : setattr(self, 'value', n.get_str_value()),
            "variableTypes": lambda n : setattr(self, 'variable_types', n.get_object_value(CreateCustomWafRuleModel_variableTypes)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_float_value("actionType", self.action_type)
        writer.write_float_value("operatorType", self.operator_type)
        writer.write_float_value("severityType", self.severity_type)
        writer.write_collection_of_primitive_values("transformationTypes", self.transformation_types)
        writer.write_str_value("value", self.value)
        writer.write_object_value("variableTypes", self.variable_types)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .create_waf_rate_limit_rule_model import CreateWafRateLimitRuleModel

@dataclass
class UpdateWafRateLimitRequest(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The ruleConfiguration property
    rule_configuration: Optional[CreateWafRateLimitRuleModel] = None
    # The ruleDescription property
    rule_description: Optional[str] = None
    # The ruleName property
    rule_name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> UpdateWafRateLimitRequest:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: UpdateWafRateLimitRequest
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return UpdateWafRateLimitRequest()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .create_waf_rate_limit_rule_model import CreateWafRateLimitRuleModel

        from .create_waf_rate_limit_rule_model import CreateWafRateLimitRuleModel

        fields: Dict[str, Callable[[Any], None]] = {
            "ruleConfiguration": lambda n : setattr(self, 'rule_configuration', n.get_object_value(CreateWafRateLimitRuleModel)),
            "ruleDescription": lambda n : setattr(self, 'rule_description', n.get_str_value()),
            "ruleName": lambda n : setattr(self, 'rule_name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("ruleConfiguration", self.rule_configuration)
        writer.write_str_value("ruleDescription", self.rule_description)
        writer.write_str_value("ruleName", self.rule_name)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .affiliate_details_result_affiliate_clicks_chart import AffiliateDetailsResult_AffiliateClicksChart
    from .affiliate_details_result_affiliate_signups_chart import AffiliateDetailsResult_AffiliateSignupsChart

@dataclass
class AffiliateDetailsResult(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The amount of affiliate credits on the account
    affiliate_balance: Optional[float] = None
    # The constructed affiliate click history chart data
    affiliate_clicks_chart: Optional[AffiliateDetailsResult_AffiliateClicksChart] = None
    # The constructed affiliate signup history chart data
    affiliate_signups_chart: Optional[AffiliateDetailsResult_AffiliateSignupsChart] = None
    # The affiliate URL for the currently authenticated user
    affiliate_url: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> AffiliateDetailsResult:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: AffiliateDetailsResult
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return AffiliateDetailsResult()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .affiliate_details_result_affiliate_clicks_chart import AffiliateDetailsResult_AffiliateClicksChart
        from .affiliate_details_result_affiliate_signups_chart import AffiliateDetailsResult_AffiliateSignupsChart

        from .affiliate_details_result_affiliate_clicks_chart import AffiliateDetailsResult_AffiliateClicksChart
        from .affiliate_details_result_affiliate_signups_chart import AffiliateDetailsResult_AffiliateSignupsChart

        fields: Dict[str, Callable[[Any], None]] = {
            "AffiliateBalance": lambda n : setattr(self, 'affiliate_balance', n.get_float_value()),
            "AffiliateClicksChart": lambda n : setattr(self, 'affiliate_clicks_chart', n.get_object_value(AffiliateDetailsResult_AffiliateClicksChart)),
            "AffiliateSignupsChart": lambda n : setattr(self, 'affiliate_signups_chart', n.get_object_value(AffiliateDetailsResult_AffiliateSignupsChart)),
            "AffiliateUrl": lambda n : setattr(self, 'affiliate_url', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_float_value("AffiliateBalance", self.affiliate_balance)
        writer.write_object_value("AffiliateClicksChart", self.affiliate_clicks_chart)
        writer.write_object_value("AffiliateSignupsChart", self.affiliate_signups_chart)
        writer.write_str_value("AffiliateUrl", self.affiliate_url)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

@dataclass
class CleanupUnconfiguredResolutionsData(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The availableResolutionsAfter property
    available_resolutions_after: Optional[List[str]] = None
    # The deletedOriginal property
    deleted_original: Optional[bool] = None
    # The deletedStorageObjects property
    deleted_storage_objects: Optional[bool] = None
    # The modifiedPlaylist property
    modified_playlist: Optional[bool] = None
    # The resolutionsToDelete property
    resolutions_to_delete: Optional[List[str]] = None
    # The resolutionsToDeleteFromMp4 property
    resolutions_to_delete_from_mp4: Optional[List[str]] = None
    # The resolutionsToDeleteFromPlaylist property
    resolutions_to_delete_from_playlist: Optional[List[str]] = None
    # The resolutionsToDeleteFromStorage property
    resolutions_to_delete_from_storage: Optional[List[str]] = None
    # The storageObjectsToDelete property
    storage_objects_to_delete: Optional[List[str]] = None
    # The updatedAvailableResolutions property
    updated_available_resolutions: Optional[bool] = None
    # The videoId property
    video_id: Optional[str] = None
    # The videoLibraryId property
    video_library_id: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> CleanupUnconfiguredResolutionsData:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: CleanupUnconfiguredResolutionsData
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return CleanupUnconfiguredResolutionsData()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        fields: Dict[str, Callable[[Any], None]] = {
            "availableResolutionsAfter": lambda n : setattr(self, 'available_resolutions_after', n.get_collection_of_primitive_values(str)),
            "deletedOriginal": lambda n : setattr(self, 'deleted_original', n.get_bool_value()),
            "deletedStorageObjects": lambda n : setattr(self, 'deleted_storage_objects', n.get_bool_value()),
            "modifiedPlaylist": lambda n : setattr(self, 'modified_playlist', n.get_bool_value()),
            "resolutionsToDelete": lambda n : setattr(self, 'resolutions_to_delete', n.get_collection_of_primitive_values(str)),
            "resolutionsToDeleteFromMp4": lambda n : setattr(self, 'resolutions_to_delete_from_mp4', n.get_collection_of_primitive_values(str)),
            "resolutionsToDeleteFromPlaylist": lambda n : setattr(self, 'resolutions_to_delete_from_playlist', n.get_collection_of_primitive_values(str)),
            "resolutionsToDeleteFromStorage": lambda n : setattr(self, 'resolutions_to_delete_from_storage', n.get_collection_of_primitive_values(str)),
            "storageObjectsToDelete": lambda n : setattr(self, 'storage_objects_to_delete', n.get_collection_of_primitive_values(str)),
            "updatedAvailableResolutions": lambda n : setattr(self, 'updated_available_resolutions', n.get_bool_value()),
            "videoId": lambda n : setattr(self, 'video_id', n.get_str_value()),
            "videoLibraryId": lambda n : setattr(self, 'video_library_id', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("availableResolutionsAfter", self.available_resolutions_after)
        writer.write_bool_value("deletedOriginal", self.deleted_original)
        writer.write_bool_value("deletedStorageObjects", self.deleted_storage_objects)
        writer.write_bool_value("modifiedPlaylist", self.modified_playlist)
        writer.write_collection_of_primitive_values("resolutionsToDelete", self.resolutions_to_delete)
        writer.write_collection_of_primitive_values("resolutionsToDeleteFromMp4", self.resolutions_to_delete_from_mp4)
        writer.write_collection_of_primitive_values("resolutionsToDeleteFromPlaylist", self.resolutions_to_delete_from_playlist)
        writer.write_collection_of_primitive_values("resolutionsToDeleteFromStorage", self.resolutions_to_delete_from_storage)
        writer.write_collection_of_primitive_values("storageObjectsToDelete", self.storage_objects_to_delete)
        writer.write_bool_value("updatedAvailableResolutions", self.updated_available_resolutions)
        writer.write_str_value("videoId", self.video_id)
        writer.write_int_value("videoLibraryId", self.video_library_id)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .pull_zone_waf_config_variable_model import PullZoneWafConfigVariableModel

@dataclass
class ShieldZoneResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The customWafRulesLimit property
    custom_waf_rules_limit: Optional[int] = None
    # The dDoSChallengeWindow property
    d_do_s_challenge_window: Optional[int] = None
    # The dDoSShieldSensitivity property
    d_do_s_shield_sensitivity: Optional[float] = None
    # The learningMode property
    learning_mode: Optional[bool] = None
    # The learningModeUntil property
    learning_mode_until: Optional[datetime.datetime] = None
    # The planType property
    plan_type: Optional[float] = None
    # The pullZoneId property
    pull_zone_id: Optional[int] = None
    # The rateLimitRulesLimit property
    rate_limit_rules_limit: Optional[int] = None
    # The shieldZoneId property
    shield_zone_id: Optional[int] = None
    # The wafDisabledRuleGroups property
    waf_disabled_rule_groups: Optional[List[str]] = None
    # The wafDisabledRules property
    waf_disabled_rules: Optional[List[str]] = None
    # The wafEnabled property
    waf_enabled: Optional[bool] = None
    # The wafEngineConfig property
    waf_engine_config: Optional[List[PullZoneWafConfigVariableModel]] = None
    # The wafExecutionMode property
    waf_execution_mode: Optional[float] = None
    # The wafLogOnlyRules property
    waf_log_only_rules: Optional[List[str]] = None
    # The wafProfileId property
    waf_profile_id: Optional[int] = None
    # The wafRequestHeaderLoggingEnabled property
    waf_request_header_logging_enabled: Optional[bool] = None
    # The wafRequestIgnoredHeaders property
    waf_request_ignored_headers: Optional[List[str]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ShieldZoneResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ShieldZoneResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ShieldZoneResponse()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .pull_zone_waf_config_variable_model import PullZoneWafConfigVariableModel

        from .pull_zone_waf_config_variable_model import PullZoneWafConfigVariableModel

        fields: Dict[str, Callable[[Any], None]] = {
            "customWafRulesLimit": lambda n : setattr(self, 'custom_waf_rules_limit', n.get_int_value()),
            "dDoSChallengeWindow": lambda n : setattr(self, 'd_do_s_challenge_window', n.get_int_value()),
            "dDoSShieldSensitivity": lambda n : setattr(self, 'd_do_s_shield_sensitivity', n.get_float_value()),
            "learningMode": lambda n : setattr(self, 'learning_mode', n.get_bool_value()),
            "learningModeUntil": lambda n : setattr(self, 'learning_mode_until', n.get_datetime_value()),
            "planType": lambda n : setattr(self, 'plan_type', n.get_float_value()),
            "pullZoneId": lambda n : setattr(self, 'pull_zone_id', n.get_int_value()),
            "rateLimitRulesLimit": lambda n : setattr(self, 'rate_limit_rules_limit', n.get_int_value()),
            "shieldZoneId": lambda n : setattr(self, 'shield_zone_id', n.get_int_value()),
            "wafDisabledRuleGroups": lambda n : setattr(self, 'waf_disabled_rule_groups', n.get_collection_of_primitive_values(str)),
            "wafDisabledRules": lambda n : setattr(self, 'waf_disabled_rules', n.get_collection_of_primitive_values(str)),
            "wafEnabled": lambda n : setattr(self, 'waf_enabled', n.get_bool_value()),
            "wafEngineConfig": lambda n : setattr(self, 'waf_engine_config', n.get_collection_of_object_values(PullZoneWafConfigVariableModel)),
            "wafExecutionMode": lambda n : setattr(self, 'waf_execution_mode', n.get_float_value()),
            "wafLogOnlyRules": lambda n : setattr(self, 'waf_log_only_rules', n.get_collection_of_primitive_values(str)),
            "wafProfileId": lambda n : setattr(self, 'waf_profile_id', n.get_int_value()),
            "wafRequestHeaderLoggingEnabled": lambda n : setattr(self, 'waf_request_header_logging_enabled', n.get_bool_value()),
            "wafRequestIgnoredHeaders": lambda n : setattr(self, 'waf_request_ignored_headers', n.get_collection_of_primitive_values(str)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_int_value("customWafRulesLimit", self.custom_waf_rules_limit)
        writer.write_int_value("dDoSChallengeWindow", self.d_do_s_challenge_window)
        writer.write_float_value("dDoSShieldSensitivity", self.d_do_s_shield_sensitivity)
        writer.write_bool_value("learningMode", self.learning_mode)
        writer.write_datetime_value("learningModeUntil", self.learning_mode_until)
        writer.write_float_value("planType", self.plan_type)
        writer.write_int_value("pullZoneId", self.pull_zone_id)
        writer.write_int_value("rateLimitRulesLimit", self.rate_limit_rules_limit)
        writer.write_int_value("shieldZoneId", self.shield_zone_id)
        writer.write_collection_of_primitive_values("wafDisabledRuleGroups", self.waf_disabled_rule_groups)
        writer.write_collection_of_primitive_values("wafDisabledRules", self.waf_disabled_rules)
        writer.write_bool_value("wafEnabled", self.waf_enabled)
        writer.write_collection_of_object_values("wafEngineConfig", self.waf_engine_config)
        writer.write_float_value("wafExecutionMode", self.waf_execution_mode)
        writer.write_collection_of_primitive_values("wafLogOnlyRules", self.waf_log_only_rules)
        writer.write_int_value("wafProfileId", self.waf_profile_id)
        writer.write_bool_value("wafRequestHeaderLoggingEnabled", self.waf_request_header_logging_enabled)
        writer.write_collection_of_primitive_values("wafRequestIgnoredHeaders", self.waf_request_ignored_headers)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .edge_script_variable import EdgeScriptVariable
    from .integration import Integration
    from .linked_pull_zone import LinkedPullZone

@dataclass
class Script(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The CurrentReleaseId property
    current_release_id: Optional[int] = None
    # The DefaultHostname property
    default_hostname: Optional[str] = None
    # The Deleted property
    deleted: Optional[bool] = None
    # The DeploymentKey property
    deployment_key: Optional[str] = None
    # The EdgeScriptVariables property
    edge_script_variables: Optional[List[EdgeScriptVariable]] = None
    # The Id property
    id: Optional[int] = None
    # The Integration property
    integration: Optional[Integration] = None
    # The IntegrationId property
    integration_id: Optional[int] = None
    # The LastModified property
    last_modified: Optional[datetime.datetime] = None
    # The LinkedPullZones property
    linked_pull_zones: Optional[List[LinkedPullZone]] = None
    # The MonthlyCost property
    monthly_cost: Optional[float] = None
    # The MonthlyCpuTime property
    monthly_cpu_time: Optional[int] = None
    # The MonthlyRequestCount property
    monthly_request_count: Optional[int] = None
    # The Name property
    name: Optional[str] = None
    # The RepositoryId property
    repository_id: Optional[int] = None
    # The ScriptType property
    script_type: Optional[float] = None
    # The SystemHostname property
    system_hostname: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> Script:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: Script
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return Script()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .edge_script_variable import EdgeScriptVariable
        from .integration import Integration
        from .linked_pull_zone import LinkedPullZone

        from .edge_script_variable import EdgeScriptVariable
        from .integration import Integration
        from .linked_pull_zone import LinkedPullZone

        fields: Dict[str, Callable[[Any], None]] = {
            "CurrentReleaseId": lambda n : setattr(self, 'current_release_id', n.get_int_value()),
            "DefaultHostname": lambda n : setattr(self, 'default_hostname', n.get_str_value()),
            "Deleted": lambda n : setattr(self, 'deleted', n.get_bool_value()),
            "DeploymentKey": lambda n : setattr(self, 'deployment_key', n.get_str_value()),
            "EdgeScriptVariables": lambda n : setattr(self, 'edge_script_variables', n.get_collection_of_object_values(EdgeScriptVariable)),
            "Id": lambda n : setattr(self, 'id', n.get_int_value()),
            "Integration": lambda n : setattr(self, 'integration', n.get_object_value(Integration)),
            "IntegrationId": lambda n : setattr(self, 'integration_id', n.get_int_value()),
            "LastModified": lambda n : setattr(self, 'last_modified', n.get_datetime_value()),
            "LinkedPullZones": lambda n : setattr(self, 'linked_pull_zones', n.get_collection_of_object_values(LinkedPullZone)),
            "MonthlyCost": lambda n : setattr(self, 'monthly_cost', n.get_float_value()),
            "MonthlyCpuTime": lambda n : setattr(self, 'monthly_cpu_time', n.get_int_value()),
            "MonthlyRequestCount": lambda n : setattr(self, 'monthly_request_count', n.get_int_value()),
            "Name": lambda n : setattr(self, 'name', n.get_str_value()),
            "RepositoryId": lambda n : setattr(self, 'repository_id', n.get_int_value()),
            "ScriptType": lambda n : setattr(self, 'script_type', n.get_float_value()),
            "SystemHostname": lambda n : setattr(self, 'system_hostname', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("Integration", self.integration)
        writer.write_str_value("Name", self.name)
        writer.write_float_value("ScriptType", self.script_type)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .resolutions import Resolutions

@dataclass
class VideoResolutionsInfoData(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: Dict[str, Any] = field(default_factory=dict)

    # The availableResolutions property
    available_resolutions: Optional[List[str]] = None
    # The configuredResolutions property
    configured_resolutions: Optional[List[str]] = None
    # The hasOriginal property
    has_original: Optional[bool] = None
    # The mp4Resolutions property
    mp4_resolutions: Optional[Resolutions] = None
    # The playlistResolutions property
    playlist_resolutions: Optional[Resolutions] = None
    # The storageResolutions property
    storage_resolutions: Optional[Resolutions] = None
    # The videoId property
    video_id: Optional[str] = None
    # The videoLibraryId property
    video_library_id: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> VideoResolutionsInfoData:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: VideoResolutionsInfoData
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return VideoResolutionsInfoData()
    
    def get_field_deserializers(self,) -> Dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: Dict[str, Callable[[ParseNode], None]]
        """
        from .resolutions import Resolutions

        from .resolutions import Resolutions

        fields: Dict[str, Callable[[Any], None]] = {
            "availableResolutions": lambda n : setattr(self, 'available_resolutions', n.get_collection_of_primitive_values(str)),
            "configuredResolutions": lambda n : setattr(self, 'configured_resolutions', n.get_collection_of_primitive_values(str)),
            "hasOriginal": lambda n : setattr(self, 'has_original', n.get_bool_value()),
            "mp4Resolutions": lambda n : setattr(self, 'mp4_resolutions', n.get_object_value(Resolutions)),
            "playlistResolutions": lambda n : setattr(self, 'playlist_resolutions', n.get_object_value(Resolutions)),
            "storageResolutions": lambda n : setattr(self, 'storage_resolutions', n.get_object_value(Resolutions)),
            "videoId": lambda n : setattr(self, 'video_id', n.get_str_value()),
            "videoLibraryId": lambda n : setattr(self, 'video_library_id', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("availableResolutions", self.available_resolutions)
        writer.write_collection_of_primitive_values("configuredResolutions", self.configured_resolutions)
        writer.write_bool_value("hasOriginal", self.has_original)
        writer.write_object_value("mp4Resolutions", self.mp4_resolutions)
        writer.write_object_value("playlistResolutions", self.playlist_resolutions)
        writer.write_object_value("storageResolutions", self.storage_resolutions)
        writer.write_str_value("videoId", self.video_id)
        writer.write_int_value("videoLibraryId", self.video_library_id)
        writer.write_additional_data_value(self.additional_data)
    

